==> node-api-hitbtc-1.0.18.tgz: package/lib/privateApi.js <==
var axios = require('axios');
var crypto = require('crypto');
var querystring = require('querystring');

var HitbtcPrivate = function(api) {
  this.endPoint = "https://api.hitbtc.com/api/3";
  this.apikey = api.api_key;
  this.secret = api.secret_key;
  this.timeout = 5000;
  this.keepalive = false;
};

var privateApi = module.exports = function(api) {
  return new HitbtcPrivate(api);
};

HitbtcPrivate.prototype.query = function(options) {
  Object.assign(options,{
    auth: { 'username': this.apikey,'password': this.secret },
    timeout: this.timeout,
    forever: this.keepalive
  });
  return axios(options).then(function(json) {
    return json
  }).catch(function(err) {
    console.log(err);
    throw new Error(err.statusCode);
  });
};

HitbtcPrivate.prototype.getQuery = function(path, query) {
  var options = {
    method: "GET",
    url: this.endPoint + path,
    qs: query,
    json: true
  };
  return this.query(options);
};

HitbtcPrivate.prototype.otherQuery = function(method, path, query) {
  var options = {
    method: method,
    url: this.endPoint + path,
    body: query,
    json: true
  };
  return this.query(options);
};

//
// SPOT Trading
//

HitbtcPrivate.prototype.getSpotBalance = function() {
  const path="/spot/balance";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getSpotOrders = function(options) {
  const path="/spot/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getSpotOrder = function(order_id) {
  const path="/spot/order/" + order_id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.newSpotOrder = function(options) {
  const path="/spot/order";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.replaceSpotOrder = function(order_id, options) {
  const path="/spot/order/" + order_id;
  return this.otherQuery("PATCH,"path, options);
};

HitbtcPrivate.prototype.cancelSpotOrders = function() {
  const path="/spot/order";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.cancelSpotOrder = function(order_id) {
  const path="/spot/order/" + order_id;
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.getSpotFees = function() {
  const path="/spot/fee";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getSpotFee = function(symbol) {
  const path="/spot/fee/" + symbol;
  return this.getQuery(path, {});
};

//
// SPOT Trading History
//

HitbtcPrivate.prototype.getSpotOrderHistory = function(options) {
  const path="/spot/history/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getSpotTradeHistory = function(options) {
  const path="/spot/history/trade";
  return this.getQuery(path, options);
};

//
// MARGIN Trading
// 

HitbtcPrivate.prototype.getMarginAccounts = function() {
  const path="/margin/account";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getMarginAccount = function(symbol) {
  const path="/margin/account/isolated/" + symbol;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.createUpdateMarginAccount = function(symbol, options) {
  const path="/margin/account/isolated/" + symbol;
  return this.otherQuery("PUT,"path, options);
};

HitbtcPrivate.prototype.closeMarginPositions = function() {
  const path="/margin/position";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.closeMarginPosition = function(symbol,options) {
  const path="/margin/position/isolated/" + symbol;
  return this.otherQuery("DELETE",path, options);
};

HitbtcPrivate.prototype.getMarginOrders = function(options) {
  const path="/margin/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getMarginOrder = function(order_id) {
  const path="/margin/order/" + order_id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.newMarginOrder = function(options) {
  const path="/margin/order";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.replaceMarginOrder = function(order_id, options) {
  const path="/margin/order/" + order_id;
  return this.otherQuery("PATCH,"path, options);
};

HitbtcPrivate.prototype.cancelMarginOrders = function() {
  const path="/margin/order";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.cancelMarginOrder = function(order_id) {
  const path="/margin/order/" + order_id;
  return this.otherQuery("DELETE",path, {});
};

//
// MARGIN Trading History
//

HitbtcPrivate.prototype.getMarginOrderHistory = function(options) {
  const path="/margin/history/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getMarginTradeHistory = function(options) {
  const path="/margin/history/trade";
  return this.getQuery(path, options);
};

//
// FUTURES Trading
//

HitbtcPrivate.prototype.getFuturesBalance = function() {
  const path="/futures/balance";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getFuturesAccounts = function() {
  const path="/futures/account";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getFuturesAccount = function(symbol) {
  const path="/futures/account/isolated/" + symbol;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.createUpdateFuturesAccount = function(symbol, options) {
  const path="/futures/account/isolated/" + symbol;
  return this.otherQuery("PUT,"path, options);
};

HitbtcPrivate.prototype.closeFuturesPositions = function() {
  const path="/futures/position";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.closeFuturesPosition = function(symbol,options) {
  const path="/futures/position/isolated/" + symbol;
  return this.otherQuery("DELETE",path, options);
};

HitbtcPrivate.prototype.getFuturesOrders = function(options) {
  const path="/futures/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getFuturesOrder = function(order_id) {
  const path="/futures/order/" + order_id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.newFuturesOrder = function(options) {
  const path="/spot/order";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.replaceFuturesOrder = function(order_id, options) {
  const path="/futures/order/" + order_id;
  return this.otherQuery("PATCH,"path, options);
};

HitbtcPrivate.prototype.cancelFuturesOrders = function() {
  const path="/futures/order";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.cancelFuturesOrder = function(order_id) {
  const path="/futures/order/" + order_id;
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.getFuturesFees = function() {
  const path="/futures/fee";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getFuturesFee = function(symbol) {
  const path="/futures/fee/" + symbol;
  return this.getQuery(path, {});
};

//
// FUTURES Trading History
//

HitbtcPrivate.prototype.getFuturesOrderHistory = function(options) {
  const path="/futures/history/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getFuturesTradeHistory = function(options) {
  const path="/futures/history/trade";
  return this.getQuery(path, options);
};

//
// WALLET Management
//

HitbtcPrivate.prototype.getWalletBalance = function() {
  const path="/wallet/balance";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getDepositAddress = function(options) {
  const path="/wallet/crypto/address";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.createDepositAddress = function(options) {
  const path="/wallet/crypto/address";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.getRecentDepositAddresses = function(options) {
  const path="/wallet/crypto/address/recent-deposit";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getRecentWithdrawAddresses = function(options) {
  const path="/wallet/crypto/address/recent-withdraw";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.withdrawCrypto = function(options) {
  const path="/wallet/crypto/withdraw";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.convertCrypto = function(options) {
  const path="/wallet/crypto/withdraw";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.withdrawCommit = function(id) {
  const path="/wallet/crypto/withdraw/" + id;
  return this.otherQuery("POST"path, {});
};

HitbtcPrivate.prototype.withdrawCommit = function(id) {
  const path="/wallet/crypto/withdraw/" + id;
  return this.otherQuery("PUT"path, {});
};

HitbtcPrivate.prototype.withdrawRollback = function(id) {
  const path="/wallet/crypto/withdraw/" + id;
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.checkMine = function(addr) {
  const path="/wallet/crypto/address/check-mine/" + addr;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.transferExchange = function(options) {
  const path="/wallet/transfer";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.transferInternal = function(options) {
  const path="/wallet/internal/withdraw";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.getTransactions = function(options) {
  const path="/wallet/transactions";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getTransaction = function(id) {
  const path="/wallet/transactions/" + id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.checkOffchainAvailable = function(options) {
  const path="/wallet/crypto/check-offchain-available";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.withdrawFee = function(options) {
  const path="/wallet/crypto/fee/estimate";
  return this.getQuery(path, {});
};

//
// SUB-ACCOUNTS Management
//

HitbtcPrivate.prototype.getSubaccounts = function() {
  const path="/sub-account";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.freezeSubaccount = function(options) {
  const path="/sub-account/freeze";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.activateSubaccount = function(options) {
  const path="/sub-account/activate";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.transferFunds = function(options) {
  const path="/sub-account/transfer";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.getACL = function(options) {
  const path="/sub-account/acl";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.changeACL = function(options) {
  const path="/sub-account/acl";
  return this.otherQuery("POST,"path, options);
};

HitbtcPrivate.prototype.getSubaccountBalance = function(id) {
  const path="/sub-account/balance/" + id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getSubaccountAddress = function(id, currency) {
  var path="/sub-account/crypto/address/" + id + "/" + currency;
  return this.getQuery(path, {});
};

==> node-api-hitbtc-1.0.19.tgz: package/lib/privateApi.js <==
var axios = require('axios');
var crypto = require('crypto');
var querystring = require('querystring');

var HitbtcPrivate = function(api) {
  this.endPoint = "https://api.hitbtc.com/api/3";
  this.apikey = api.api_key;
  this.secret = api.secret_key;
  this.timeout = 5000;
  this.keepalive = false;
};

var privateApi = module.exports = function(api) {
  return new HitbtcPrivate(api);
};

HitbtcPrivate.prototype.query = function(options) {
  Object.assign(options,{
    auth: { 'username': this.apikey,'password': this.secret },
    timeout: this.timeout,
    forever: this.keepalive
  });
  return axios(options).then(function(json) {
    return json
  }).catch(function(err) {
    console.log(err);
    throw new Error(err.statusCode);
  });
};

HitbtcPrivate.prototype.getQuery = function(path, query) {
  var options = {
    method: "GET",
    url: this.endPoint + path,
    qs: query,
    json: true
  };
  return this.query(options);
};

HitbtcPrivate.prototype.otherQuery = function(method, path, query) {
  var options = {
    method: method,
    url: this.endPoint + path,
    body: query,
    json: true
  };
  return this.query(options);
};

//
// SPOT Trading
//

HitbtcPrivate.prototype.getSpotBalance = function() {
  const path="/spot/balance";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getSpotOrders = function(options) {
  const path="/spot/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getSpotOrder = function(order_id) {
  const path="/spot/order/" + order_id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.newSpotOrder = function(options) {
  const path="/spot/order";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.replaceSpotOrder = function(order_id, options) {
  const path="/spot/order/" + order_id;
  return this.otherQuery("PATCH",path, options);
};

HitbtcPrivate.prototype.cancelSpotOrders = function() {
  const path="/spot/order";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.cancelSpotOrder = function(order_id) {
  const path="/spot/order/" + order_id;
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.getSpotFees = function() {
  const path="/spot/fee";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getSpotFee = function(symbol) {
  const path="/spot/fee/" + symbol;
  return this.getQuery(path, {});
};

//
// SPOT Trading History
//

HitbtcPrivate.prototype.getSpotOrderHistory = function(options) {
  const path="/spot/history/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getSpotTradeHistory = function(options) {
  const path="/spot/history/trade";
  return this.getQuery(path, options);
};

//
// MARGIN Trading
// 

HitbtcPrivate.prototype.getMarginAccounts = function() {
  const path="/margin/account";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getMarginAccount = function(symbol) {
  const path="/margin/account/isolated/" + symbol;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.createUpdateMarginAccount = function(symbol, options) {
  const path="/margin/account/isolated/" + symbol;
  return this.otherQuery("PUT",path, options);
};

HitbtcPrivate.prototype.closeMarginPositions = function() {
  const path="/margin/position";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.closeMarginPosition = function(symbol,options) {
  const path="/margin/position/isolated/" + symbol;
  return this.otherQuery("DELETE",path, options);
};

HitbtcPrivate.prototype.getMarginOrders = function(options) {
  const path="/margin/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getMarginOrder = function(order_id) {
  const path="/margin/order/" + order_id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.newMarginOrder = function(options) {
  const path="/margin/order";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.replaceMarginOrder = function(order_id, options) {
  const path="/margin/order/" + order_id;
  return this.otherQuery("PATCH",path, options);
};

HitbtcPrivate.prototype.cancelMarginOrders = function() {
  const path="/margin/order";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.cancelMarginOrder = function(order_id) {
  const path="/margin/order/" + order_id;
  return this.otherQuery("DELETE",path, {});
};

//
// MARGIN Trading History
//

HitbtcPrivate.prototype.getMarginOrderHistory = function(options) {
  const path="/margin/history/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getMarginTradeHistory = function(options) {
  const path="/margin/history/trade";
  return this.getQuery(path, options);
};

//
// FUTURES Trading
//

HitbtcPrivate.prototype.getFuturesBalance = function() {
  const path="/futures/balance";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getFuturesAccounts = function() {
  const path="/futures/account";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getFuturesAccount = function(symbol) {
  const path="/futures/account/isolated/" + symbol;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.createUpdateFuturesAccount = function(symbol, options) {
  const path="/futures/account/isolated/" + symbol;
  return this.otherQuery("PUT",path, options);
};

HitbtcPrivate.prototype.closeFuturesPositions = function() {
  const path="/futures/position";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.closeFuturesPosition = function(symbol,options) {
  const path="/futures/position/isolated/" + symbol;
  return this.otherQuery("DELETE",path, options);
};

HitbtcPrivate.prototype.getFuturesOrders = function(options) {
  const path="/futures/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getFuturesOrder = function(order_id) {
  const path="/futures/order/" + order_id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.newFuturesOrder = function(options) {
  const path="/spot/order";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.replaceFuturesOrder = function(order_id, options) {
  const path="/futures/order/" + order_id;
  return this.otherQuery("PATCH",path, options);
};

HitbtcPrivate.prototype.cancelFuturesOrders = function() {
  const path="/futures/order";
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.cancelFuturesOrder = function(order_id) {
  const path="/futures/order/" + order_id;
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.getFuturesFees = function() {
  const path="/futures/fee";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getFuturesFee = function(symbol) {
  const path="/futures/fee/" + symbol;
  return this.getQuery(path, {});
};

//
// FUTURES Trading History
//

HitbtcPrivate.prototype.getFuturesOrderHistory = function(options) {
  const path="/futures/history/order";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getFuturesTradeHistory = function(options) {
  const path="/futures/history/trade";
  return this.getQuery(path, options);
};

//
// WALLET Management
//

HitbtcPrivate.prototype.getWalletBalance = function() {
  const path="/wallet/balance";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getDepositAddress = function(options) {
  const path="/wallet/crypto/address";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.createDepositAddress = function(options) {
  const path="/wallet/crypto/address";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.getRecentDepositAddresses = function(options) {
  const path="/wallet/crypto/address/recent-deposit";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getRecentWithdrawAddresses = function(options) {
  const path="/wallet/crypto/address/recent-withdraw";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.withdrawCrypto = function(options) {
  const path="/wallet/crypto/withdraw";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.convertCrypto = function(options) {
  const path="/wallet/crypto/withdraw";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.withdrawCommit = function(id) {
  const path="/wallet/crypto/withdraw/" + id;
  return this.otherQuery("POST"path, {});
};

HitbtcPrivate.prototype.withdrawCommit = function(id) {
  const path="/wallet/crypto/withdraw/" + id;
  return this.otherQuery("PUT"path, {});
};

HitbtcPrivate.prototype.withdrawRollback = function(id) {
  const path="/wallet/crypto/withdraw/" + id;
  return this.otherQuery("DELETE",path, {});
};

HitbtcPrivate.prototype.checkMine = function(addr) {
  const path="/wallet/crypto/address/check-mine/" + addr;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.transferExchange = function(options) {
  const path="/wallet/transfer";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.transferInternal = function(options) {
  const path="/wallet/internal/withdraw";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.getTransactions = function(options) {
  const path="/wallet/transactions";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.getTransaction = function(id) {
  const path="/wallet/transactions/" + id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.checkOffchainAvailable = function(options) {
  const path="/wallet/crypto/check-offchain-available";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.withdrawFee = function(options) {
  const path="/wallet/crypto/fee/estimate";
  return this.getQuery(path, {});
};

//
// SUB-ACCOUNTS Management
//

HitbtcPrivate.prototype.getSubaccounts = function() {
  const path="/sub-account";
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.freezeSubaccount = function(options) {
  const path="/sub-account/freeze";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.activateSubaccount = function(options) {
  const path="/sub-account/activate";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.transferFunds = function(options) {
  const path="/sub-account/transfer";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.getACL = function(options) {
  const path="/sub-account/acl";
  return this.getQuery(path, options);
};

HitbtcPrivate.prototype.changeACL = function(options) {
  const path="/sub-account/acl";
  return this.otherQuery("POST",path, options);
};

HitbtcPrivate.prototype.getSubaccountBalance = function(id) {
  const path="/sub-account/balance/" + id;
  return this.getQuery(path, {});
};

HitbtcPrivate.prototype.getSubaccountAddress = function(id, currency) {
  var path="/sub-account/crypto/address/" + id + "/" + currency;
  return this.getQuery(path, {});
};
